aboutsummaryrefslogtreecommitdiffstats
path: root/src/modules/m_sakick.cpp
diff options
context:
space:
mode:
authorGravatar Sadie Powell2020-10-26 23:40:24 +0000
committerGravatar Sadie Powell2020-10-27 00:59:11 +0000
commit7cb27dabe695505d2eb7b942c4fbf518dda8e6b3 (patch)
tree12f7541d3389efa9a084d2a4859d6ce4ede43b03 /src/modules/m_sakick.cpp
parentReplace the check for eventfd() with a C++17 header check. (diff)
Convert CmdResult to an 8-bit strongly typed enum.
Diffstat (limited to 'src/modules/m_sakick.cpp')
-rw-r--r--src/modules/m_sakick.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/modules/m_sakick.cpp b/src/modules/m_sakick.cpp
index 0bb69c7e8..5a8675263 100644
--- a/src/modules/m_sakick.cpp
+++ b/src/modules/m_sakick.cpp
@@ -48,17 +48,17 @@ class CommandSakick : public Command
if (dest->server->IsULine())
{
user->WriteNumeric(ERR_NOPRIVILEGES, "Cannot use an SA command on a U-lined client");
- return CMD_FAILURE;
+ return CmdResult::FAILURE;
}
if (!channel->HasUser(dest))
{
user->WriteNotice("*** " + dest->nick + " is not on " + channel->name);
- return CMD_FAILURE;
+ return CmdResult::FAILURE;
}
/* For local clients, directly kick them. For remote clients,
* just return CMD_SUCCESS knowing the protocol module will route the SAKICK to the user's
* local server and that will kick them instead.
*/
if (IS_LOCAL(dest))
@@ -68,14 +68,14 @@ class CommandSakick : public Command
ServerInstance->SNO.WriteGlobalSno('a', user->nick + " SAKICKed " + dest->nick + " on " + channel->name);
}
- return CMD_SUCCESS;
+ return CmdResult::SUCCESS;
}
else
{
user->WriteNotice("*** Invalid nickname or channel");
}
- return CMD_FAILURE;
+ return CmdResult::FAILURE;
}
RouteDescriptor GetRouting(User* user, const Params& parameters) override
@@ -48,17 +48,17 @@ class CommandSakick : public Command
}
/* For local clients, directly kick them. For remote clients,
- * just return CMD_SUCCESS knowing the protocol module will route the SAKICK to the user's
+ * just return CmdResult::SUCCESS knowing the protocol module will route the SAKICK to the user's
* local server and that will kick them instead.
*/